from django.test import Client
from django.test import SimpleTestCase

from adminlte2_templates.core import reverse


class ContextTestCase(SimpleTestCase):
    def setUp(self):
        self.client = Client()

    def context_exists(self, context):
        # Get view from 'layouts' unit test
        response = self.client.get(reverse('layouts:default_boxed'))
        try:
            return response.context[context] is not None
        except KeyError:
            return False

    def test_debug_context(self):
        self.assertTrue(self.context_exists('DEBUG'))

    def test_html_lang_context(self):
        self.assertTrue(self.context_exists('ADMINLTE_HTML_LANG'))

    def test_html_lang_bidi_context(self):
        self.assertTrue(self.context_exists('ADMINLTE_HTML_LANG_BIDI'))

    def test_skin_style_context(self):
        self.assertTrue(self.context_exists('ADMINLTE_SKIN_STYLE'))

    def test_control_style_context(self):
        self.assertTrue(self.context_exists('ADMINLTE_CONTROL_STYLE'))

    def test_footer_version_context(self):
        self.assertTrue(self.context_exists('ADMINLTE_FOOTER_VERSION'))

    def test_use_shim_context(self):
        self.assertTrue(self.context_exists('ADMINLTE_USE_SHIM'))

    def test_use_cdn_context(self):
        self.assertTrue(self.context_exists('ADMINLTE_USE_CDN'))

    def test_use_cdn_context_true(self):
        with self.settings(ADMINLTE_USE_CDN=True):
            self.assertTrue(self.context_exists('ADMINLTE_CDN_ADMINLTE_CSS_CORE'))
            self.assertTrue(self.context_exists('ADMINLTE_CDN_ADMINLTE_CSS_SKIN'))
            self.assertTrue(self.context_exists('ADMINLTE_CDN_ADMINLTE_JS_CORE'))
            self.assertTrue(self.context_exists('ADMINLTE_CDN_BOOTSTRAP_CSS_CORE'))
            self.assertTrue(self.context_exists('ADMINLTE_CDN_BOOTSTRAP_JS_CORE'))
            self.assertTrue(self.context_exists('ADMINLTE_CDN_JQUERY_JS_CORE'))

    def test_use_cdn_context_false(self):
        with self.settings(ADMINLTE_USE_CDN=False):
            self.assertFalse(self.context_exists('ADMINLTE_CDN_ADMINLTE_CSS_CORE'))
            self.assertFalse(self.context_exists('ADMINLTE_CDN_ADMINLTE_CSS_SKIN'))
            self.assertFalse(self.context_exists('ADMINLTE_CDN_ADMINLTE_JS_CORE'))
            self.assertFalse(self.context_exists('ADMINLTE_CDN_BOOTSTRAP_CSS_CORE'))
            self.assertFalse(self.context_exists('ADMINLTE_CDN_BOOTSTRAP_JS_CORE'))
            self.assertFalse(self.context_exists('ADMINLTE_CDN_JQUERY_JS_CORE'))

    #   Shims
    def test_use_cdn_and_use_shim_context_true(self):
        with self.settings(ADMINLTE_USE_CDN=True, ADMINLTE_USE_SHIM=True):
            self.assertTrue(self.context_exists('ADMINLTE_CDN_HTML5SHIV_JS_CORE'))
            self.assertTrue(self.context_exists('ADMINLTE_CDN_RESPOND_JS_CORE'))

    def test_use_cdn_and_use_shim_context_false(self):
        with self.settings(ADMINLTE_USE_CDN=True, ADMINLTE_USE_SHIM=False):
            self.assertFalse(self.context_exists('ADMINLTE_CDN_HTML5SHIV_JS_CORE'))
            self.assertFalse(self.context_exists('ADMINLTE_CDN_RESPOND_JS_CORE'))

    #   DataTables
    def test_use_cdn_and_enable_datatables_context_true(self):
        with self.settings(ADMINLTE_USE_CDN=True, ADMINLTE_STATIC_ENABLE_DATATABLES=True):
            self.assertTrue(self.context_exists('ADMINLTE_CDN_DATATABLES_CSS_CORE'))
            self.assertTrue(self.context_exists('ADMINLTE_CDN_DATATABLES_JS_CORE'))

    def test_use_cdn_and_enable_datatables_context_false(self):
        with self.settings(ADMINLTE_USE_CDN=True, ADMINLTE_STATIC_ENABLE_DATATABLES=False):
            self.assertFalse(self.context_exists('ADMINLTE_CDN_DATATABLES_CSS_CORE'))
            self.assertFalse(self.context_exists('ADMINLTE_CDN_DATATABLES_JS_CORE'))

    #   Font Awesome
    def test_use_cdn_and_enable_fontawesome_context_true(self):
        with self.settings(ADMINLTE_USE_CDN=True, ADMINLTE_STATIC_ENABLE_FONTAWESOME=True):
            self.assertTrue(self.context_exists('ADMINLTE_CDN_FONTAWESOME_CSS_CORE'))

    def test_use_cdn_and_enable_fontawesome_context_false(self):
        with self.settings(ADMINLTE_USE_CDN=True, ADMINLTE_STATIC_ENABLE_FONTAWESOME=False):
            self.assertFalse(self.context_exists('ADMINLTE_CDN_FONTAWESOME_CSS_CORE'))

    #   Select2
    def test_use_cdn_and_enable_select2_context_true(self):
        with self.settings(ADMINLTE_USE_CDN=True, ADMINLTE_STATIC_ENABLE_SELECT2=True):
            self.assertTrue(self.context_exists('ADMINLTE_CDN_SELECT2_CSS_CORE'))

    def test_use_cdn_and_enable_select2_context_false(self):
        with self.settings(ADMINLTE_USE_CDN=True, ADMINLTE_STATIC_ENABLE_SELECT2=False):
            self.assertFalse(self.context_exists('ADMINLTE_CDN_SELECT2_CSS_CORE'))



from django.contrib.auth.models import User
from django.template.exceptions import TemplateSyntaxError
from django.test import Client
from django.test import TestCase

from adminlte2_templates.core import reverse


class GravatarUrlTestCase(TestCase):
    """
    Test cases for {% gravatar_url %} template tag

    Testing these cases for both authenticated and non-authenticated clients:

        * Sanity check
        * 'size', 'default', 'force_default', 'rating' 'user' params
        * 'ADMINLTE_GRAVATAR_SIZE','ADMINLTE_GRAVATAR_DEFAULT',
            'ADMINLTE_GRAVATAR_FORCE_DEFAULT' 'ADMINLTE_GRAVATAR_RATING' settings
        * Overriding settings with params
        * Raising TemplateSyntaxError on invalid 'size', 'default', 'rating' params
    """
    URL_PATTERN_INDEX = 'gravatar_url:index'
    URL_PATTERN_INVALID_DEFAULT = 'gravatar_url:invalid_default'
    URL_PATTERN_INVALID_SIZE_MAX = 'gravatar_url:invalid_size_max'
    URL_PATTERN_INVALID_SIZE_MIN = 'gravatar_url:invalid_size_min'
    URL_PATTERN_INVALID_RATING = 'gravatar_url:invalid_rating'

    USER_USERNAME = 'mari'
    USER_EMAIL = 'josemari.manio@gmail.com'
    USER_PASSWORD = 'maripassword'  # nosec

    def setUp(self):
        self.client = Client()
        self.user = User.objects.create_user(self.USER_USERNAME, self.USER_EMAIL, self.USER_PASSWORD)

    def get_response_with_auth(self):
        self.client.login(username=self.USER_USERNAME, password=self.USER_PASSWORD)
        return self.client.get(reverse(self.URL_PATTERN_INDEX))

    def get_response_without_auth(self):
        return self.client.get(reverse(self.URL_PATTERN_INDEX))

    def get_response_invalid_default(self):
        return self.client.get(reverse(self.URL_PATTERN_INVALID_DEFAULT))

    def get_response_invalid_size_max(self):
        return self.client.get(reverse(self.URL_PATTERN_INVALID_SIZE_MAX))

    def get_response_invalid_size_min(self):
        return self.client.get(reverse(self.URL_PATTERN_INVALID_SIZE_MIN))

    def get_response_invalid_rating(self):
        return self.client.get(reverse(self.URL_PATTERN_INVALID_RATING))

    #
    #   With authentication
    #
    def test_with_auth(self):
        self.assertContains(self.get_response_with_auth(), '<img id="check-auth" src="https://www.gravatar.com/avatar'
                                                           '/b88d14ec6a751900484d421f8303824f?s=80&d=mp&r=pg&f=">',
                            html=True)

    # Tag parameters
    def test_with_auth_tag_param_size(self):
        self.assertContains(self.get_response_with_auth(), '<img id="param-size" src="https://www.gravatar.com/avatar'
                                                           '/b88d14ec6a751900484d421f8303824f?s=100&d=mp&r=pg&f=">',
                            html=True)

    def test_with_auth_tag_param_default(self):
        self.assertContains(self.get_response_with_auth(),
                            '<img id="param-default" src="https://www.gravatar.com/avatar'
                            '/b88d14ec6a751900484d421f8303824f?s=80&d=retro&r=pg&f=">', html=True)

    def test_with_auth_tag_param_force_default(self):
        self.assertContains(self.get_response_with_auth(),
                            '<img id="param-force-default" src="https://www.gravatar.com/avatar'
                            '/b88d14ec6a751900484d421f8303824f?s=80&d=mp&r=pg&f=y">', html=True)

    def test_with_auth_tag_param_rating(self):
        self.assertContains(self.get_response_with_auth(), '<img id="param-rating" src="https://www.gravatar.com/avatar'
                                                           '/b88d14ec6a751900484d421f8303824f?s=80&d=mp&r=r&f=">',
                            html=True)

    def test_with_auth_tag_param_user(self):
        self.assertContains(self.get_response_with_auth(), '<img id="param-user" src="https://www.gravatar.com/avatar'
                                                           '/b88d14ec6a751900484d421f8303824f?s=80&d=mp&r=pg&f=">',
                            html=True)

    def test_with_auth_tag_param_all(self):
        self.assertContains(self.get_response_with_auth(), '<img id="all-params" src="https://www.gravatar.com/avatar'
                                                           '/b88d14ec6a751900484d421f8303824f?s=100&d=retro&r=r&f=y">',
                            html=True)

    # Settings
    def test_with_auth_settings_param_size(self):
        with self.settings(ADMINLTE_GRAVATAR_SIZE=100):
            self.assertContains(self.get_response_with_auth(),
                                '<img id="check-auth" src="https://www.gravatar.com/avatar'
                                '/b88d14ec6a751900484d421f8303824f?s=100&d=mp&r=pg&f=">', html=True)

    def test_with_auth_settings_param_default(self):
        with self.settings(ADMINLTE_GRAVATAR_DEFAULT='retro'):
            self.assertContains(self.get_response_with_auth(),
                                '<img id="check-auth" src="https://www.gravatar.com/avatar'
                                '/b88d14ec6a751900484d421f8303824f?s=80&d=retro&r=pg&f=">', html=True)

    def test_with_auth_settings_param_force_default(self):
        with self.settings(ADMINLTE_GRAVATAR_FORCE_DEFAULT=True):
            self.assertContains(self.get_response_with_auth(),
                                '<img id="check-auth" src="https://www.gravatar.com/avatar'
                                '/b88d14ec6a751900484d421f8303824f?s=80&d=mp&r=pg&f=y">', html=True)

    def test_with_auth_settings_param_rating(self):
        with self.settings(ADMINLTE_GRAVATAR_RATING='r'):
            self.assertContains(self.get_response_with_auth(),
                                '<img id="check-auth" src="https://www.gravatar.com/avatar'
                                '/b88d14ec6a751900484d421f8303824f?s=80&d=mp&r=r&f=">', html=True)

    def test_with_auth_settings_param_all(self):
        with self.settings(ADMINLTE_GRAVATAR_SIZE=100, ADMINLTE_GRAVATAR_DEFAULT='retro',
                           ADMINLTE_GRAVATAR_FORCE_DEFAULT=True, ADMINLTE_GRAVATAR_RATING='r'):
            self.assertContains(self.get_response_with_auth(),
                                '<img id="check-auth" src="https://www.gravatar.com/avatar'
                                '/b88d14ec6a751900484d421f8303824f?s=100&d=retro&r=r&f=y">', html=True)

    # Overriding settings with tag parameters
    def test_with_auth_override_settings_with_tag_param_size(self):
        with self.settings(ADMINLTE_GRAVATAR_SIZE=80):
            self.assertContains(self.get_response_with_auth(),
                                '<img id="param-size" src="https://www.gravatar.com/avatar'
                                '/b88d14ec6a751900484d421f8303824f?s=100&d=mp&r=pg&f=">', html=True)

    def test_with_auth_override_settings_with_tag_param_default(self):
        with self.settings(ADMINLTE_GRAVATAR_DEFAULT='mp'):
            self.assertContains(self.get_response_with_auth(),
                                '<img id="param-default" src="https://www.gravatar.com/avatar'
                                '/b88d14ec6a751900484d421f8303824f?s=80&d=retro&r=pg&f=">', html=True)

    def test_with_auth_override_settings_with_tag_param_force_default(self):
        with self.settings(ADMINLTE_GRAVATAR_FORCE_DEFAULT=False):
            self.assertContains(self.get_response_with_auth(),
                                '<img id="param-force-default" src="https://www.gravatar.com/avatar'
                                '/b88d14ec6a751900484d421f8303824f?s=80&d=mp&r=pg&f=y">', html=True)

    def test_with_auth_override_settings_with_tag_param_rating(self):
        with self.settings(ADMINLTE_GRAVATAR_RATING='pg'):
            self.assertContains(self.get_response_with_auth(),
                                '<img id="param-rating" src="https://www.gravatar.com/avatar'
                                '/b88d14ec6a751900484d421f8303824f?s=80&d=mp&r=r&f=">', html=True)

    def test_with_auth_override_settings_with_tag_param_all(self):
        with self.settings(ADMINLTE_GRAVATAR_SIZE=80, ADMINLTE_GRAVATAR_DEFAULT='mp',
                           ADMINLTE_GRAVATAR_FORCE_DEFAULT=False, ADMINLTE_GRAVATAR_RATING='pg'):
            self.assertContains(self.get_response_with_auth(),
                                '<img id="all-params" src="https://www.gravatar.com/avatar'
                                '/b88d14ec6a751900484d421f8303824f?s=100&d=retro&r=r&f=y">', html=True)

    #
    #   Without authentication
    #
    def test_without_auth(self):
        self.assertContains(self.get_response_without_auth(), 'https://www.gravatar.com/avatar/?s=80&d=mp&r=pg&f')

    # Tag parameters
    def test_without_auth_tag_param_size(self):
        self.assertContains(self.get_response_without_auth(),
                            '<img id="param-size" src="https://www.gravatar.com/avatar'
                            '/?s=100&d=mp&r=pg&f=">', html=True)

    def test_without_auth_tag_param_default(self):
        self.assertContains(self.get_response_without_auth(),
                            '<img id="param-default" src="https://www.gravatar.com/avatar'
                            '/?s=80&d=retro&r=pg&f=">', html=True)

    def test_without_auth_tag_param_force_default(self):
        self.assertContains(self.get_response_without_auth(),
                            '<img id="param-force-default" src="https://www.gravatar.com/avatar'
                            '/?s=80&d=mp&r=pg&f=y">', html=True)

    def test_without_auth_tag_param_rating(self):
        self.assertContains(self.get_response_without_auth(),
                            '<img id="param-rating" src="https://www.gravatar.com/avatar'
                            '/?s=80&d=mp&r=r&f=">', html=True)

    def test_without_auth_tag_param_user(self):
        self.assertContains(self.get_response_without_auth(),
                            '<img id="param-user" src="https://www.gravatar.com/avatar'
                            '/?s=80&d=mp&r=pg&f=">', html=True)

    def test_without_auth_tag_param_all(self):
        self.assertContains(self.get_response_without_auth(),
                            '<img id="all-params" src="https://www.gravatar.com/avatar'
                            '/?s=100&d=retro&r=r&f=y">', html=True)

    # Settings
    def test_without_auth_settings_param_size(self):
        with self.settings(ADMINLTE_GRAVATAR_SIZE=100):
            self.assertContains(self.get_response_without_auth(),
                                '<img id="check-auth" src="https://www.gravatar.com/avatar'
                                '/?s=100&d=mp&r=pg&f=">', html=True)

    def test_without_auth_settings_param_default(self):
        with self.settings(ADMINLTE_GRAVATAR_DEFAULT='retro'):
            self.assertContains(self.get_response_without_auth(),
                                '<img id="check-auth" src="https://www.gravatar.com/avatar'
                                '/?s=80&d=retro&r=pg&f=">', html=True)

    def test_without_auth_settings_param_force_default(self):
        with self.settings(ADMINLTE_GRAVATAR_FORCE_DEFAULT=True):
            self.assertContains(self.get_response_without_auth(),
                                '<img id="check-auth" src="https://www.gravatar.com/avatar'
                                '/?s=80&d=mp&r=pg&f=y">', html=True)

    def test_without_auth_settings_param_rating(self):
        with self.settings(ADMINLTE_GRAVATAR_RATING='r'):
            self.assertContains(self.get_response_without_auth(),
                                '<img id="check-auth" src="https://www.gravatar.com/avatar'
                                '/?s=80&d=mp&r=r&f=">', html=True)

    # Override settings with tag parameters
    def test_without_auth_override_settings_with_tag_param_size(self):
        with self.settings(ADMINLTE_GRAVATAR_SIZE=80):
            self.assertContains(self.get_response_without_auth(),
                                '<img id="param-size" src="https://www.gravatar.com/avatar'
                                '/?s=100&d=mp&r=pg&f=">', html=True)

    def test_without_auth_override_settings_with_tag_param_default(self):
        with self.settings(ADMINLTE_GRAVATAR_DEFAULT='mp'):
            self.assertContains(self.get_response_without_auth(),
                                '<img id="param-default" src="https://www.gravatar.com/avatar'
                                '/?s=80&d=retro&r=pg&f=">', html=True)

    def test_without_auth_override_settings_with_tag_param_force_default(self):
        with self.settings(ADMINLTE_GRAVATAR_FORCE_DEFAULT=False):
            self.assertContains(self.get_response_without_auth(),
                                '<img id="param-force-default" src="https://www.gravatar.com/avatar'
                                '/?s=80&d=mp&r=pg&f=y">', html=True)

    def test_without_auth_override_settings_with_tag_param_rating(self):
        with self.settings(ADMINLTE_GRAVATAR_RATING='pg'):
            self.assertContains(self.get_response_without_auth(),
                                '<img id="param-rating" src="https://www.gravatar.com/avatar'
                                '/?s=80&d=mp&r=r&f=">', html=True)

    def test_without_auth_override_settings_with_tag_param_all(self):
        with self.settings(ADMINLTE_GRAVATAR_SIZE=80, ADMINLTE_GRAVATAR_DEFAULT='mp',
                           ADMINLTE_GRAVATAR_FORCE_DEFAULT=False, ADMINLTE_GRAVATAR_RATING='pg'):
            self.assertContains(self.get_response_without_auth(),
                                '<img id="all-params" src="https://www.gravatar.com/avatar'
                                '/?s=100&d=retro&r=r&f=y">', html=True)

    #
    #   Invalid parameters
    #
    def test_invalid_param_default(self):
        self.assertRaises(TemplateSyntaxError, self.get_response_invalid_default)

    def test_invalid_param_size_above_maximum(self):
        self.assertRaises(TemplateSyntaxError, self.get_response_invalid_size_max)

    def test_invalid_param_size_below_minimum(self):
        self.assertRaises(TemplateSyntaxError, self.get_response_invalid_size_min)

    def test_invalid_param_rating(self):
        self.assertRaises(TemplateSyntaxError, self.get_response_invalid_rating)



from django.conf import settings

from adminlte2_templates.core import get_settings


def template(request):
    """
        Get all settings related to the AdminLTE 2 module and return them as context variables
    """
    skin_style = get_settings('ADMINLTE_SKIN_STYLE')

    context = {
        'DEBUG': getattr(settings, 'DEBUG'),

        #
        # Footer version value
        #
        'ADMINLTE_FOOTER_VERSION': get_settings('ADMINLTE_FOOTER_VERSION'),

        #
        # HTML 'lang' attribute value
        #
        'ADMINLTE_HTML_LANG': get_settings('ADMINLTE_HTML_LANG', django_setting='LANGUAGE_CODE'),

        #
        # HTML 'dir' attribute value
        #
        'ADMINLTE_HTML_LANG_BIDI': get_settings('ADMINLTE_HTML_LANG_BIDI'),

        #
        # Skin style color. Valid values are:
        #   skin-black, skin-black-light, skin-blue, skin-blue-light, skin-green, skin-green-light, skin-purple,
        #   skin-purple-light, skin-red, skin-red-light, skin-yellow, skin-yellow-light
        #
        'ADMINLTE_SKIN_STYLE': skin_style,

        #
        # Control sidebar color. Valid values are:
        #   control-sidebar-dark, control-sidebar-light
        #
        'ADMINLTE_CONTROL_STYLE': get_settings('ADMINLTE_CONTROL_STYLE'),

        #
        # Toggle to enable optional static libraries
        #
        'ADMINLTE_STATIC_ENABLE_DATATABLES': get_settings('ADMINLTE_STATIC_ENABLE_DATATABLES'),
        'ADMINLTE_STATIC_ENABLE_FONTAWESOME': get_settings('ADMINLTE_STATIC_ENABLE_FONTAWESOME'),
        'ADMINLTE_STATIC_ENABLE_SELECT2': get_settings('ADMINLTE_STATIC_ENABLE_SELECT2'),

        #
        # Toggle to use HTML5 Shim
        #
        'ADMINLTE_USE_SHIM': get_settings('ADMINLTE_USE_SHIM'),

        #
        # Toggle to use CDN for AdminLTE dependencies
        #
        'ADMINLTE_USE_CDN': get_settings('ADMINLTE_USE_CDN'),
    }

    if context['ADMINLTE_USE_CDN']:
        #
        # Dependency CDN URLs
        #
        context.update({
            # AdminLTE 2.4.18
            'ADMINLTE_CDN_ADMINLTE_CSS_CORE': get_settings('ADMINLTE_CDN_ADMINLTE_CSS_CORE'),
            'ADMINLTE_CDN_ADMINLTE_CSS_SKIN': get_settings('ADMINLTE_CDN_ADMINLTE_CSS_SKIN')[skin_style],
            'ADMINLTE_CDN_ADMINLTE_JS_CORE': get_settings('ADMINLTE_CDN_ADMINLTE_JS_CORE'),
            # Bootstrap 3.4.1
            'ADMINLTE_CDN_BOOTSTRAP_CSS_CORE': get_settings('ADMINLTE_CDN_BOOTSTRAP_CSS_CORE'),
            'ADMINLTE_CDN_BOOTSTRAP_JS_CORE': get_settings('ADMINLTE_CDN_BOOTSTRAP_JS_CORE'),

            # jQuery 3.4.1
            'ADMINLTE_CDN_JQUERY_JS_CORE': get_settings('ADMINLTE_CDN_JQUERY_JS_CORE'),
        })

    if context['ADMINLTE_USE_CDN'] and context['ADMINLTE_USE_SHIM']:
        #
        # Shim CDN URLs
        #
        context.update({
            'ADMINLTE_CDN_HTML5SHIV_JS_CORE': get_settings('ADMINLTE_CDN_HTML5SHIV_JS_CORE'),
            'ADMINLTE_CDN_RESPOND_JS_CORE': get_settings('ADMINLTE_CDN_RESPOND_JS_CORE'),
        })

    # DataTables 1.10.21
    if context['ADMINLTE_USE_CDN'] and context['ADMINLTE_STATIC_ENABLE_DATATABLES']:
        context.update({
            'ADMINLTE_CDN_DATATABLES_CSS_CORE': get_settings('ADMINLTE_CDN_DATATABLES_CSS_CORE'),
            'ADMINLTE_CDN_DATATABLES_JS_CORE': get_settings('ADMINLTE_CDN_DATATABLES_JS_CORE'),
        })

    # Font-Awesome 4.7.0
    if context['ADMINLTE_USE_CDN'] and context['ADMINLTE_STATIC_ENABLE_FONTAWESOME']:
        context.update({
            'ADMINLTE_CDN_FONTAWESOME_CSS_CORE': get_settings('ADMINLTE_CDN_FONTAWESOME_CSS_CORE'),
        })

    # Select2 4.0.13
    if context['ADMINLTE_USE_CDN'] and context['ADMINLTE_STATIC_ENABLE_SELECT2']:
        context.update({
            'ADMINLTE_CDN_SELECT2_CSS_CORE': get_settings('ADMINLTE_CDN_SELECT2_CSS_CORE'),
            'ADMINLTE_CDN_SELECT2_JS_CORE': get_settings('ADMINLTE_CDN_SELECT2_JS_CORE'),
        })

    return context



from django.test import Client
from django.test import SimpleTestCase

from adminlte2_templates.core import reverse


class AddClassTestCase(SimpleTestCase):
    """
    Test cases for 'add_class' template filter
    """
    URL_PATTERN_INDEX = 'add_class:index'

    def setUp(self):
        self.client = Client()

    def get_response_index(self):
        return self.client.get(reverse(self.URL_PATTERN_INDEX))

    def test_add_class(self):
        self.assertContains(self.get_response_index(), 'add-class')

    def test_add_class_multiple(self):
        self.assertContains(self.get_response_index(), 'add-class-1 add-class-2')



from django.contrib.sites.models import Site
from django.template.exceptions import TemplateSyntaxError
from django.test import Client
from django.test import TestCase

from adminlte2_templates import constants as const
from adminlte2_templates.core import reverse


class PaginatorTestCase(TestCase):
    """
    Test cases for {% paginator %} template tag

    Testing these cases:

        * Sanity check
        * 'adjacent_pages', 'align', 'no_margin' params
        * Invalid 'adjacent_pages', 'align' param values
    """
    URL_PATTERN_INDEX = 'paginator:index'
    URL_PATTERN_INVALID_ADJACENT_PAGES = 'paginator:invalid_adjacent_pages'
    URL_PATTERN_INVALID_ALIGN = 'paginator:invalid_align'

    def setUp(self):
        self.client = Client()
        for n in range(5):
            n = str(n)
            Site.objects.create(domain=n, name=n)

    def get_response_page(self, page):
        return self.client.get(reverse(self.URL_PATTERN_INDEX) + '?page=' + str(page))

    def get_response_invalid_adjacent_pages(self):
        return self.client.get(reverse(self.URL_PATTERN_INVALID_ADJACENT_PAGES))

    def get_response_invalid_align(self):
        return self.client.get(reverse(self.URL_PATTERN_INVALID_ALIGN))

    #
    #   Sanity check
    #
    def test_template_used(self):
        self.assertTemplateUsed(self.get_response_page(1), const.PAGINATOR_TEMPLATE_NAME)

    def test_response_page_1(self):
        self.assertContains(self.get_response_page(1),
                            '''<div id="check"><nav>
                                    <ul id="pagination" class="pagination">
                                        <li class="active"><a href="?page=1">1</a></li>
                                        <li><a href="?page=2">2</a></li>
                                        <li><a href="?page=3">3</a></li>
                                        <li><a href="?page=2"><i class="fa fa-caret-right"></i></a></li>
                                        <li><a href="?page=last"><small>Last</small></a></li>
                                    </ul>
                                </nav></div>''', html=True)

    def test_response_page_2(self):
        self.assertContains(self.get_response_page(2),
                            '''<div id="check"><nav>
                                    <ul id="pagination" class="pagination">
                                        <li><a href="?page=1"><small>First</small></a></li>
                                        <li><a href="?page=1"><i class="fa fa-caret-left"></i></a></li>
                                        <li><a href="?page=1">1</a></li>
                                        <li class="active"><a href="?page=2">2</a></li>
                                        <li><a href="?page=3">3</a></li>
                                        <li><a href="?page=4">4</a></li>
                                        <li><a href="?page=3"><i class="fa fa-caret-right"></i></a></li>
                                        <li><a href="?page=last"><small>Last</small></a></li>
                                    </ul>
                                </nav></div>''', html=True)

    def test_response_page_3(self):
        self.assertContains(self.get_response_page(3),
                            '''<div id="check"><nav>
                                    <ul id="pagination" class="pagination">
                                        <li><a href="?page=1"><small>First</small></a></li>
                                        <li><a href="?page=2"><i class="fa fa-caret-left"></i></a></li>
                                        <li><a href="?page=1">1</a></li>
                                        <li><a href="?page=2">2</a></li>
                                        <li class="active"><a href="?page=3">3</a></li>
                                        <li><a href="?page=4">4</a></li>
                                        <li><a href="?page=5">5</a></li>
                                        <li><a href="?page=4"><i class="fa fa-caret-right"></i></a></li>
                                        <li><a href="?page=last"><small>Last</small></a></li>
                                    </ul>
                                </nav></div>''', html=True)

    def test_response_page_4(self):
        self.assertContains(self.get_response_page(4),
                            '''<div id="check"><nav>
                                    <ul id="pagination" class="pagination">
                                        <li><a href="?page=1"><small>First</small></a></li>
                                        <li><a href="?page=3"><i class="fa fa-caret-left"></i></a></li>
                                        <li><a href="?page=2">2</a></li>
                                        <li><a href="?page=3">3</a></li>
                                        <li class="active"><a href="?page=4">4</a></li>
                                        <li><a href="?page=5">5</a></li>
                                        <li><a href="?page=6">6</a></li>
                                        <li><a href="?page=5"><i class="fa fa-caret-right"></i></a></li>
                                        <li><a href="?page=last"><small>Last</small></a></li>
                                    </ul>
                                </nav></div>''', html=True)

    def test_response_page_last(self):
        self.assertContains(self.get_response_page('last'),
                            '''<div id="check"><nav>
                                    <ul id="pagination" class="pagination">
                                        <li><a href="?page=1"><small>First</small></a></li>
                                        <li><a href="?page=5"><i class="fa fa-caret-left"></i></a></li>
                                        <li><a href="?page=4">4</a></li>
                                        <li><a href="?page=5">5</a></li>
                                        <li class="active"><a href="?page=6">6</a></li>
                                    </ul>
                                </nav></div>''', html=True)

    #
    #   'adjacent_pages' parameter to 3
    #
    def test_param_adjacent_pages_page_1(self):
        self.assertContains(self.get_response_page(1),
                            '''<div id="param-adjacent-pages"><nav>
                                    <ul id="pagination" class="pagination">
                                        <li class="active"><a href="?page=1">1</a></li>
                                        <li><a href="?page=2">2</a></li>
                                        <li><a href="?page=3">3</a></li>
                                        <li><a href="?page=4">4</a></li>
                                        <li><a href="?page=2"><i class="fa fa-caret-right"></i></a></li>
                                        <li><a href="?page=last"><small>Last</small></a></li>
                                    </ul>
                                </nav></div>''', html=True)

    def test_param_adjacent_pages_page_2(self):
        self.assertContains(self.get_response_page(2),
                            '''<div id="param-adjacent-pages"><nav>
                                    <ul id="pagination" class="pagination">
                                        <li><a href="?page=1"><small>First</small></a></li>
                                        <li><a href="?page=1"><i class="fa fa-caret-left"></i></a></li>
                                        <li><a href="?page=1">1</a></li>
                                        <li class="active"><a href="?page=2">2</a></li>
                                        <li><a href="?page=3">3</a></li>
                                        <li><a href="?page=4">4</a></li>
                                        <li><a href="?page=5">5</a></li>
                                        <li><a href="?page=3"><i class="fa fa-caret-right"></i></a></li>
                                        <li><a href="?page=last"><small>Last</small></a></li>
                                    </ul>
                                </nav></div>''', html=True)

    def test_param_adjacent_pages_page_3(self):
        self.assertContains(self.get_response_page(3),
                            '''<div id="param-adjacent-pages"><nav>
                                    <ul id="pagination" class="pagination">
                                        <li><a href="?page=1"><small>First</small></a></li>
                                        <li><a href="?page=2"><i class="fa fa-caret-left"></i></a></li>
                                        <li><a href="?page=1">1</a></li>
                                        <li><a href="?page=2">2</a></li>
                                        <li class="active"><a href="?page=3">3</a></li>
                                        <li><a href="?page=4">4</a></li>
                                        <li><a href="?page=5">5</a></li>
                                        <li><a href="?page=6">6</a></li>
                                        <li><a href="?page=4"><i class="fa fa-caret-right"></i></a></li>
                                        <li><a href="?page=last"><small>Last</small></a></li>
                                    </ul>
                                </nav></div>''', html=True)

    def test_param_adjacent_pages_page_4(self):
        self.assertContains(self.get_response_page(4),
                            '''<div id="param-adjacent-pages"><nav>
                                    <ul id="pagination" class="pagination">
                                        <li><a href="?page=1"><small>First</small></a></li>
                                        <li><a href="?page=3"><i class="fa fa-caret-left"></i></a></li>
                                        <li><a href="?page=1">1</a></li>
                                        <li><a href="?page=2">2</a></li>
                                        <li><a href="?page=3">3</a></li>
                                        <li class="active"><a href="?page=4">4</a></li>
                                        <li><a href="?page=5">5</a></li>
                                        <li><a href="?page=6">6</a></li>
                                        <li><a href="?page=5"><i class="fa fa-caret-right"></i></a></li>
                                        <li><a href="?page=last"><small>Last</small></a></li>
                                    </ul>
                                </nav></div>''', html=True)

    def test_param_adjacent_pages_last(self):
        self.assertContains(self.get_response_page('last'),
                            '''<div id="param-adjacent-pages"><nav>
                                    <ul id="pagination" class="pagination">
                                        <li><a href="?page=1"><small>First</small></a></li>
                                        <li><a href="?page=5"><i class="fa fa-caret-left"></i></a></li>
                                        <li><a href="?page=3">3</a></li>
                                        <li><a href="?page=4">4</a></li>
                                        <li><a href="?page=5">5</a></li>
                                        <li class="active"><a href="?page=6">6</a></li>
                                    </ul>
                                </nav></div>''', html=True)

    #
    #   'align' parameter choices
    #
    def test_param_align_initial(self):
        self.assertContains(self.get_response_page(1),
                            '''<div id="param-align-initial"><nav>
                                    <ul id="pagination" class="pagination">
                                        <li class="active"><a href="?page=1">1</a></li>
                                        <li><a href="?page=2">2</a></li>
                                        <li><a href="?page=3">3</a></li>
                                        <li><a href="?page=2"><i class="fa fa-caret-right"></i></a></li>
                                        <li><a href="?page=last"><small>Last</small></a></li>
                                    </ul>
                                </nav></div>''', html=True)

    def test_param_align_center(self):
        self.assertContains(self.get_response_page(1),
                            '''<div id="param-align-center"><nav class="text-center">
                                    <ul id="pagination" class="pagination">
                                        <li class="active"><a href="?page=1">1</a></li>
                                        <li><a href="?page=2">2</a></li>
                                        <li><a href="?page=3">3</a></li>
                                        <li><a href="?page=2"><i class="fa fa-caret-right"></i></a></li>
                                        <li><a href="?page=last"><small>Last</small></a></li>
                                    </ul>
                                </nav></div>''', html=True)

    def test_param_align_left(self):
        self.assertContains(self.get_response_page(1),
                            '''<div id="param-align-left"><nav class="pull-left">
                                    <ul id="pagination" class="pagination">
                                        <li class="active"><a href="?page=1">1</a></li>
                                        <li><a href="?page=2">2</a></li>
                                        <li><a href="?page=3">3</a></li>
                                        <li><a href="?page=2"><i class="fa fa-caret-right"></i></a></li>
                                        <li><a href="?page=last"><small>Last</small></a></li>
                                    </ul>
                                </nav></div>''', html=True)

    def test_param_align_right(self):
        self.assertContains(self.get_response_page(1),
                            '''<div id="param-align-right"><nav class="pull-right">
                                    <ul id="pagination" class="pagination">
                                        <li class="active"><a href="?page=1">1</a></li>
                                        <li><a href="?page=2">2</a></li>
                                        <li><a href="?page=3">3</a></li>
                                        <li><a href="?page=2"><i class="fa fa-caret-right"></i></a></li>
                                        <li><a href="?page=last"><small>Last</small></a></li>
                                    </ul>
                                </nav></div>''', html=True)

    #
    #   'no_margin' parameter
    #
    def test_param_no_margin_false(self):
        self.assertContains(self.get_response_page(1),
                            '''<div id="param-no-margin-false"><nav>
                                    <ul id="pagination" class="pagination">
                                        <li class="active"><a href="?page=1">1</a></li>
                                        <li><a href="?page=2">2</a></li>
                                        <li><a href="?page=3">3</a></li>
                                        <li><a href="?page=2"><i class="fa fa-caret-right"></i></a></li>
                                        <li><a href="?page=last"><small>Last</small></a></li>
                                    </ul>
                                </nav></div>''', html=True)

    def test_param_no_margin_true(self):
        self.assertContains(self.get_response_page(1),
                            '''<div id="param-no-margin-true"><nav>
                                    <ul id="pagination" class="pagination no-margin">
                                        <li class="active"><a href="?page=1">1</a></li>
                                        <li><a href="?page=2">2</a></li>
                                        <li><a href="?page=3">3</a></li>
                                        <li><a href="?page=2"><i class="fa fa-caret-right"></i></a></li>
                                        <li><a href="?page=last"><small>Last</small></a></li>
                                    </ul>
                                </nav></div>''', html=True)

    #
    #   Test all parameters
    #
    def test_param_all(self):
        self.assertContains(self.get_response_page(1),
                            '''<div id="all-params"><nav>
                                    <ul id="pagination" class="pagination">
                                        <li class="active"><a href="?page=1">1</a></li>
                                        <li><a href="?page=2">2</a></li>
                                        <li><a href="?page=3">3</a></li>
                                        <li><a href="?page=2"><i class="fa fa-caret-right"></i></a></li>
                                        <li><a href="?page=last"><small>Last</small></a></li>
                                    </ul>
                                </nav></div>''', html=True)

    #
    #   Invalid parameter
    #
    def test_invalid_param_adjacent_pages(self):
        self.assertRaises(TypeError, self.get_response_invalid_adjacent_pages)

    def test_invalid_param_align(self):
        self.assertRaises(TemplateSyntaxError, self.get_response_invalid_align)



from django.contrib.sites.models import Site
from django.views.generic import ListView


class PaginatorListView(ListView):
    model = Site
    template_name = 'paginator/paginator.html'
    paginate_by = 1


class PaginatorInvalidAdjacentPagesListView(PaginatorListView):
    template_name = 'paginator/invalid_adjacent_pages.html'


class PaginatorInvalidAlignListView(PaginatorListView):
    template_name = 'paginator/invalid_align.html'



from django.conf.urls import url

from .views import AddActiveDetailView
from .views import AddActiveTemplateView

app_name = 'add_active'

urlpatterns = [
    url(r'^child/$',
        AddActiveTemplateView.as_view(), name='child'),
    url(r'^(?P<pk>\d+)/$',
        AddActiveDetailView.as_view(), name='pk'),
    url('',
        AddActiveTemplateView.as_view(), name='index'),
]



from django.conf import settings

from adminlte2_templates import constants

try:
    # Python 3
    from urllib.parse import urlencode
except ImportError:
    # Python 2.7
    from urllib import urlencode

try:
    # Supports >=Django 2.0
    from django.shortcuts import reverse
except ImportError:
    # Supports <=Django 1.1
    from django.core.urlresolvers import reverse


def get_settings(variable, django_setting=None):
    """
        Get the settings variable from Django ``settings``. If no settings variable
        is found, get the default value from the adminlte2_templates ``constants`` module.

        :param variable: Settings variable name
        :type variable: str

        :param django_setting: Django settings variable to look for before trying to get ``variable``
        :type django_setting: str, optional

        :return: Settings value
    """
    return getattr(settings, django_setting if django_setting else variable, getattr(constants, variable, None))



from django.views.generic import TemplateView


class GravatarUrlTemplateView(TemplateView):
    template_name = 'gravatar_url/gravatar_url.html'

    def get_context_data(self, **kwargs):
        context = super(GravatarUrlTemplateView, self).get_context_data(**kwargs)
        context['user_obj'] = self.request.user
        return context


class GravatarUrlInvalidDefaultTemplateView(TemplateView):
    template_name = 'gravatar_url/invalid_default.html'


class GravatarUrlInvalidSizeMinTemplateView(TemplateView):
    template_name = 'gravatar_url/invalid_size_min.html'


class GravatarUrlInvalidSizeMaxTemplateView(TemplateView):
    template_name = 'gravatar_url/invalid_size_max.html'


class GravatarUrlInvalidRatingTemplateView(TemplateView):
    template_name = 'gravatar_url/invalid_rating.html'



from django.conf.urls import url

from . import views

app_name = 'gravatar_url'

urlpatterns = [
    url(r'^invalid-default/$',
        views.GravatarUrlInvalidDefaultTemplateView.as_view(), name='invalid_default'),
    url(r'^invalid-rating/$',
        views.GravatarUrlInvalidRatingTemplateView.as_view(), name='invalid_rating'),
    url(r'^invalid-size-max/$',
        views.GravatarUrlInvalidSizeMaxTemplateView.as_view(), name='invalid_size_max'),
    url(r'^invalid-size-min/$',
        views.GravatarUrlInvalidSizeMinTemplateView.as_view(), name='invalid_size_min'),
    url('',
        views.GravatarUrlTemplateView.as_view(), name='index'),
]



from django.conf.urls import url

from . import views

app_name = 'layouts'

urlpatterns = [
    #
    #   Default
    #
    url(r'^default-boxed/$',
        views.DefaultBoxedTemplateView.as_view(), name='default_boxed'),
    url(r'^default-collapsed/$',
        views.DefaultCollapsedTemplateView.as_view(), name='default_collapsed'),
    url(r'^default-fixed/$',
        views.DefaultFixedTemplateView.as_view(), name='default_fixed'),
    url(r'^default-login/$',
        views.DefaultLoginTemplateView.as_view(), name='default_login'),
    url(r'^default-register/$',
        views.DefaultRegisterTemplateView.as_view(), name='default_register'),
    url(r'^default-top-nav/$',
        views.DefaultTopNavTemplateView.as_view(), name='default_top_nav'),
    #
    #   Barebones
    #
    url(r'^barebones-boxed/$',
        views.BarebonesBoxedTemplateView.as_view(), name='barebones_boxed'),
    url(r'^barebones-collapsed/$',
        views.BarebonesCollapsedTemplateView.as_view(), name='barebones_collapsed'),
    url(r'^barebones-fixed/$',
        views.BarebonesFixedTemplateView.as_view(), name='barebones_fixed'),
    url(r'^barebones-top-nav/$',
        views.BarebonesTopNavTemplateView.as_view(), name='barebones_top_nav'),
    #
    #   No Breadcrumbs
    #
    url(r'^no-breadcrumbs-boxed/$',
        views.NoBreadcrumbsBoxedTemplateView.as_view(), name='no_breadcrumbs_boxed'),
    url(r'^no-breadcrumbs-collapsed/$',
        views.NoBreadcrumbsCollapsedTemplateView.as_view(), name='no_breadcrumbs_collapsed'),
    url(r'^no-breadcrumbs-fixed/$',
        views.NoBreadcrumbsFixedTemplateView.as_view(), name='no_breadcrumbs_fixed'),
    url(r'^no-breadcrumbs-top-nav/$',
        views.NoBreadcrumbsTopNavTemplateView.as_view(), name='no_breadcrumbs_top_nav'),
    #
    #   No Breadcrumbs, No Footer
    #
    url(r'^no-breadcrumbs-footer-boxed/$',
        views.NoBreadcrumbsFooterBoxedTemplateView.as_view(), name='no_breadcrumbs_footer_boxed'),
    url(r'^no-breadcrumbs-footer-collapsed/$',
        views.NoBreadcrumbsFooterCollapsedTemplateView.as_view(), name='no_breadcrumbs_footer_collapsed'),
    url(r'^no-breadcrumbs-footer-fixed/$',
        views.NoBreadcrumbsFooterFixedTemplateView.as_view(), name='no_breadcrumbs_footer_fixed'),
    url(r'^no-breadcrumbs-footer-top-nav/$',
        views.NoBreadcrumbsFooterTopNavTemplateView.as_view(), name='no_breadcrumbs_footer_top_nav'),
    #
    #   No Content Header
    #
    url(r'^no-content-header-boxed/$',
        views.NoContentHeaderBoxedTemplateView.as_view(), name='no_content_header_boxed'),
    url(r'^no-content-header-collapsed/$',
        views.NoContentHeaderCollapsedTemplateView.as_view(), name='no_content_header_collapsed'),
    url(r'^no-content-header-fixed/$',
        views.NoContentHeaderFixedTemplateView.as_view(), name='no_content_header_fixed'),
    url(r'^no-content-header-top-nav/$',
        views.NoContentHeaderTopNavTemplateView.as_view(), name='no_content_header_top_nav'),
    #
    #   No Footer
    #
    url(r'^no-footer-boxed/$',
        views.NoFooterBoxedTemplateView.as_view(), name='no_footer_boxed'),
    url(r'^no-footer-collapsed/$',
        views.NoFooterCollapsedTemplateView.as_view(), name='no_footer_collapsed'),
    url(r'^no-footer-fixed/$',
        views.NoFooterFixedTemplateView.as_view(), name='no_footer_fixed'),
    url(r'^no-footer-top-nav/$',
        views.NoFooterTopNavTemplateView.as_view(), name='no_footer_top_nav'),
]



from django.conf.urls import url

from . import views

app_name = 'page_title'

urlpatterns = [
    url(r'^list/$',
        views.PageTitleListView.as_view(), name='list'),
    url(r'^override/$',
        views.PageTitleOverridePageNameTemplateView.as_view(), name='override'),
    url('',
        views.PageTitleTemplateView.as_view(), name='index'),
]



from django.contrib.sites.models import Site
from django.views.generic import ListView
from django.views.generic import TemplateView


class PageTitleTemplateView(TemplateView):
    template_name = 'page_title/page_title.html'


class PageTitleOverridePageNameTemplateView(PageTitleTemplateView):
    def get_context_data(self, **kwargs):
        context = super(PageTitleOverridePageNameTemplateView, self).get_context_data(**kwargs)
        context['page_name'] = 'Override'
        return context


class PageTitleListView(ListView):
    template_name = 'page_title/page_title.html'
    model = Site
    paginate_by = 1



from django.views.generic import TemplateView

from adminlte2_templates import constants as const


#
#   Default
#
class DefaultBoxedTemplateView(TemplateView):
    template_name = const.LAYOUT_DEFAULT_BOXED


class DefaultCollapsedTemplateView(TemplateView):
    template_name = const.LAYOUT_DEFAULT_COLLAPSED


class DefaultFixedTemplateView(TemplateView):
    template_name = const.LAYOUT_DEFAULT_FIXED


class DefaultLoginTemplateView(TemplateView):
    template_name = const.LAYOUT_DEFAULT_LOGIN


class DefaultRegisterTemplateView(TemplateView):
    template_name = const.LAYOUT_DEFAULT_REGISTER


class DefaultTopNavTemplateView(TemplateView):
    template_name = const.LAYOUT_DEFAULT_TOP_NAV


#
#   Barebones
#
class BarebonesBoxedTemplateView(TemplateView):
    template_name = const.LAYOUT_BAREBONES_BOXED


class BarebonesCollapsedTemplateView(TemplateView):
    template_name = const.LAYOUT_BAREBONES_COLLAPSED


class BarebonesFixedTemplateView(TemplateView):
    template_name = const.LAYOUT_BAREBONES_FIXED


class BarebonesTopNavTemplateView(TemplateView):
    template_name = const.LAYOUT_BAREBONES_TOP_NAV


#
#   No Breadcrumbs
#
class NoBreadcrumbsBoxedTemplateView(TemplateView):
    template_name = const.LAYOUT_NO_BREADCRUMBS_BOXED


class NoBreadcrumbsCollapsedTemplateView(TemplateView):
    template_name = const.LAYOUT_NO_BREADCRUMBS_COLLAPSED


class NoBreadcrumbsFixedTemplateView(TemplateView):
    template_name = const.LAYOUT_NO_BREADCRUMBS_FIXED


class NoBreadcrumbsTopNavTemplateView(TemplateView):
    template_name = const.LAYOUT_NO_BREADCRUMBS_TOP_NAV


#
#   No Breadcrumbs, No Footer
#
class NoBreadcrumbsFooterBoxedTemplateView(TemplateView):
    template_name = const.LAYOUT_NO_BREADCRUMBS_FOOTER_BOXED


class NoBreadcrumbsFooterCollapsedTemplateView(TemplateView):
    template_name = const.LAYOUT_NO_BREADCRUMBS_FOOTER_COLLAPSED


class NoBreadcrumbsFooterFixedTemplateView(TemplateView):
    template_name = const.LAYOUT_NO_BREADCRUMBS_FOOTER_FIXED


class NoBreadcrumbsFooterTopNavTemplateView(TemplateView):
    template_name = const.LAYOUT_NO_BREADCRUMBS_FOOTER_TOP_NAV


#
#   No Content Header
#
class NoContentHeaderBoxedTemplateView(TemplateView):
    template_name = const.LAYOUT_NO_CONTENT_HEADER_BOXED


class NoContentHeaderCollapsedTemplateView(TemplateView):
    template_name = const.LAYOUT_NO_CONTENT_HEADER_COLLAPSED


class NoContentHeaderFixedTemplateView(TemplateView):
    template_name = const.LAYOUT_NO_CONTENT_HEADER_FIXED


class NoContentHeaderTopNavTemplateView(TemplateView):
    template_name = const.LAYOUT_NO_CONTENT_HEADER_TOP_NAV


#
#   No Footer
#
class NoFooterBoxedTemplateView(TemplateView):
    template_name = const.LAYOUT_NO_FOOTER_BOXED


class NoFooterCollapsedTemplateView(TemplateView):
    template_name = const.LAYOUT_NO_FOOTER_COLLAPSED


class NoFooterFixedTemplateView(TemplateView):
    template_name = const.LAYOUT_NO_FOOTER_FIXED


class NoFooterTopNavTemplateView(TemplateView):
    template_name = const.LAYOUT_NO_FOOTER_TOP_NAV



from django.test import Client
from django.test import TestCase

from adminlte2_templates.core import reverse


class AddActiveTestCase(TestCase):
    """
    Test cases for {% add_active %} template tag

    Testing these cases:

        * Sanity check
        * 'exact_match', 'not_when' params
        * 'pk' arg
    """
    URL_PATTERN_INDEX = 'add_active:index'
    URL_PATTERN_CHILD = 'add_active:child'
    URL_PATTERN_PK = 'add_active:pk'

    def setUp(self):
        self.client = Client()

    def get_response_index(self):
        return self.client.get(reverse(self.URL_PATTERN_INDEX))

    def get_response_child(self):
        return self.client.get(reverse(self.URL_PATTERN_CHILD))

    def get_response_pk(self, pk):
        return self.client.get(reverse(self.URL_PATTERN_PK, args=(pk,)))

    #
    #   Sanity check
    #
    def test_with_active(self):
        self.assertContains(self.get_response_child(), '<p id="with-active"> active </p>', html=True)

    def test_without_active(self):
        self.assertContains(self.get_response_index(), '<p id="without-active"></p>', html=True)

    #
    #   'exact_match' parameter
    #
    def test_exact_match_true(self):
        self.assertContains(self.get_response_child(), '<p id="exact-match-true"></p>', html=True)

    def test_exact_match_false(self):
        self.assertContains(self.get_response_child(), '<p id="exact-match-false"> active </p>', html=True)

    #
    #   'not_when' parameter
    #
    def test_not_when_with_match(self):
        self.assertContains(self.get_response_index(), '<p id="not-when-with-match"></p>', html=True)

    def test_not_when_with_match_multiple(self):
        self.assertContains(self.get_response_index(), '<p id="not-when-with-match-multiple"></p>', html=True)

    def test_not_when_without_match(self):
        self.assertContains(self.get_response_index(), '<p id="not-when-without-match"> active </p>', html=True)

    def test_not_when_without_match_multiple(self):
        self.assertContains(self.get_response_index(), '<p id="not-when-without-match-multiple"> active </p>',
                            html=True)

    #
    #   'pk' arg
    #
    def test_detailview_pk(self):
        self.assertContains(self.get_response_pk(1), '<p id="detailview-pk"> active </p>', html=True)



import os

BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))

SECRET_KEY = '!t_(11ght0&nmb&$tf4to=gdg&u$!hsm3@)c6dzp=zdc*c9zci'  # nosec

INSTALLED_APPS = [
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.sites',

    'adminlte2_templates',

    'tests',
]

MIDDLEWARE = [
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
]

ROOT_URLCONF = 'tests.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'APP_DIRS': True,
        'DIRS': [os.path.join(BASE_DIR, 'tests/templates')],
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'adminlte2_templates.context_processors.template',
            ],
        },
    },
]

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': os.path.join(BASE_DIR, 'db.sqlite3'),
    }
}

PASSWORD_HASHERS = [
    'django.contrib.auth.hashers.MD5PasswordHasher',
]



from django.test import Client
from django.test import SimpleTestCase

from adminlte2_templates import constants as const
from adminlte2_templates.core import reverse


class TemplateTestCase(SimpleTestCase):

    def setUp(self):
        self.client = Client()

    #
    #   Default
    #
    def test_default_boxed(self):
        self.assertTemplateUsed(
            self.client.get(reverse('layouts:default_boxed')),
            const.LAYOUT_DEFAULT_BOXED)

    def test_default_collapsed(self):
        self.assertTemplateUsed(
            self.client.get(reverse('layouts:default_collapsed')),
            const.LAYOUT_DEFAULT_COLLAPSED)

    def test_default_fixed(self):
        self.assertTemplateUsed(
            self.client.get(reverse('layouts:default_fixed')),
            const.LAYOUT_DEFAULT_FIXED)

    def test_default_login(self):
        self.assertTemplateUsed(
            self.client.get(reverse('layouts:default_login')),
            const.LAYOUT_DEFAULT_LOGIN)

    def test_default_register(self):
        self.assertTemplateUsed(
            self.client.get(reverse('layouts:default_register')),
            const.LAYOUT_DEFAULT_REGISTER)

    def test_default_top_nav(self):
        self.assertTemplateUsed(
            self.client.get(reverse('layouts:default_top_nav')),
            const.LAYOUT_DEFAULT_TOP_NAV)

    #
    #   Barebones
    #
    def test_barebones_boxed(self):
        self.assertTemplateUsed(
            self.client.get(reverse('layouts:barebones_boxed')),
            const.LAYOUT_BAREBONES_BOXED)

    def test_barebones_collapsed(self):
        self.assertTemplateUsed(
            self.client.get(reverse('layouts:barebones_collapsed')),
            const.LAYOUT_BAREBONES_COLLAPSED)

    def test_barebones_fixed(self):
        self.assertTemplateUsed(
            self.client.get(reverse('layouts:barebones_fixed')),
            const.LAYOUT_BAREBONES_FIXED)

    def test_barebones_top_nav(self):
        self.assertTemplateUsed(
            self.client.get(reverse('layouts:barebones_top_nav')),
            const.LAYOUT_BAREBONES_TOP_NAV)

    #
    #   No Breadcrumbs
    #
    def test_no_breadcrumbs_boxed(self):
        self.assertTemplateUsed(
            self.client.get(reverse('layouts:no_breadcrumbs_boxed')),
            const.LAYOUT_NO_BREADCRUMBS_BOXED)

    def test_no_breadcrumbs_collapsed(self):
        self.assertTemplateUsed(
            self.client.get(reverse('layouts:no_breadcrumbs_collapsed')),
            const.LAYOUT_NO_BREADCRUMBS_COLLAPSED)

    def test_no_breadcrumbs_fixed(self):
        self.assertTemplateUsed(
            self.client.get(reverse('layouts:no_breadcrumbs_fixed')),
            const.LAYOUT_NO_BREADCRUMBS_FIXED)

    def test_no_breadcrumbs_top_nav(self):
        self.assertTemplateUsed(
            self.client.get(reverse('layouts:no_breadcrumbs_top_nav')),
            const.LAYOUT_NO_BREADCRUMBS_TOP_NAV)

    #
    #   No Breadcrumbs, No Footer
    #
    def test_no_breadcrumbs_footer_boxed(self):
        self.assertTemplateUsed(
            self.client.get(reverse('layouts:no_breadcrumbs_footer_boxed')),
            const.LAYOUT_NO_BREADCRUMBS_FOOTER_BOXED)

    def test_no_breadcrumbs_footer_collapsed(self):
        self.assertTemplateUsed(
            self.client.get(reverse('layouts:no_breadcrumbs_footer_collapsed')),
            const.LAYOUT_NO_BREADCRUMBS_FOOTER_COLLAPSED)

    def test_no_breadcrumbs_footer_fixed(self):
        self.assertTemplateUsed(
            self.client.get(reverse('layouts:no_breadcrumbs_footer_fixed')),
            const.LAYOUT_NO_BREADCRUMBS_FOOTER_FIXED)

    def test_no_breadcrumbs_footer_top_nav(self):
        self.assertTemplateUsed(
            self.client.get(reverse('layouts:no_breadcrumbs_footer_top_nav')),
            const.LAYOUT_NO_BREADCRUMBS_FOOTER_TOP_NAV)

    #
    #   No Content Header
    #
    def test_no_content_header_boxed(self):
        self.assertTemplateUsed(
            self.client.get(reverse('layouts:no_content_header_boxed')),
            const.LAYOUT_NO_CONTENT_HEADER_BOXED)

    def test_no_content_header_collapsed(self):
        self.assertTemplateUsed(
            self.client.get(reverse('layouts:no_content_header_collapsed')),
            const.LAYOUT_NO_CONTENT_HEADER_COLLAPSED)

    def test_no_content_header_fixed(self):
        self.assertTemplateUsed(
            self.client.get(reverse('layouts:no_content_header_fixed')),
            const.LAYOUT_NO_CONTENT_HEADER_FIXED)

    def test_no_content_header_top_nav(self):
        self.assertTemplateUsed(
            self.client.get(reverse('layouts:no_content_header_top_nav')),
            const.LAYOUT_NO_CONTENT_HEADER_TOP_NAV)

    #
    #   No Footer
    #
    def test_no_footer_boxed(self):
        self.assertTemplateUsed(
            self.client.get(reverse('layouts:no_footer_boxed')),
            const.LAYOUT_NO_FOOTER_BOXED)

    def test_no_footer_collapsed(self):
        self.assertTemplateUsed(
            self.client.get(reverse('layouts:no_footer_collapsed')),
            const.LAYOUT_NO_FOOTER_COLLAPSED)

    def test_no_footer_fixed(self):
        self.assertTemplateUsed(
            self.client.get(reverse('layouts:no_footer_fixed')),
            const.LAYOUT_NO_FOOTER_FIXED)

    def test_no_footer_top_nav(self):
        self.assertTemplateUsed(
            self.client.get(reverse('layouts:no_footer_top_nav')),
            const.LAYOUT_NO_FOOTER_TOP_NAV)



from django.conf.urls import url

from . import views

app_name = 'paginator'

urlpatterns = [
    url(r'^invalid-adjacent-pages/$',
        views.PaginatorInvalidAdjacentPagesListView.as_view(), name='invalid_adjacent_pages'),
    url(r'^invalid-align/$',
        views.PaginatorInvalidAlignListView.as_view(), name='invalid_align'),
    url('',
        views.PaginatorListView.as_view(), name='index'),
]



from django.contrib.sites.models import Site
from django.views.generic import DetailView
from django.views.generic import TemplateView


class AddActiveTemplateView(TemplateView):
    template_name = 'add_active/add_active.html'


class AddActiveDetailView(DetailView):
    model = Site
    template_name = 'add_active/add_active.html'



from django.conf.urls import url

try:
    # Supports >=Django 2.0
    from django.urls import include
except ImportError:
    # Supports <=Django 1.1
    from django.conf.urls import include

urlpatterns = [
    url(r'^add-active/', include('tests.add_active.urls')),
    url(r'^add-class/', include('tests.add_class.urls')),
    url(r'^gravatar-url/', include('tests.gravatar_url.urls')),
    url(r'^page-title/', include('tests.page_title.urls')),
    url(r'^paginator/', include('tests.paginator.urls')),
    url(r'^layouts/', include('tests.layouts.urls')),
]



import io

from setuptools import find_packages
from setuptools import setup

from adminlte2_templates import __version__

with io.open('README.rst', 'rt', encoding='utf8') as f:
    README = f.read()

setup(
    name='django-adminlte2-templates',
    version=__version__,
    description='AdminLTE 2 templates for Django',
    long_description=README,
    url='https://github.com/josemarimanio/django-adminlte2-templates/',
    project_urls={
        'Documentation': 'https://django-adminlte2-templates.readthedocs.io/en/latest/',
        'Source Code': 'https://github.com/josemarimanio/django-adminlte2-templates/',
    },
    author='Jose Mari Manio',
    author_email='josemari.manio@outlook.com',
    license='MIT',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django :: 1.11',
        'Framework :: Django :: 2.2',
        'Framework :: Django :: 3.0',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
    packages=find_packages(),
    include_package_data=True,
    python_requires='>=2.7',
    install_requires=['django>=1.11', ],
)



import hashlib

from django import template
from django.core.exceptions import ImproperlyConfigured
from django.urls.exceptions import NoReverseMatch
from django.utils.safestring import mark_safe
from django.template.exceptions import TemplateSyntaxError

from adminlte2_templates import constants as const
from adminlte2_templates.core import get_settings
from adminlte2_templates.core import reverse
from adminlte2_templates.core import urlencode

try:
    # {% page_title %} Django 'sites' framework support
    from django.contrib.sites.models import Site
    from django.contrib.sites.shortcuts import get_current_site
except RuntimeError:
    pass

register = template.Library()


@register.simple_tag(takes_context=True)
def add_active(context, url_pattern, *args, **kwargs):
    """
    Add class ``active`` to sidebar and header navigation links based on comparison of URL pattern with current URL.

    Based on django-adminlte2 templatetags
     https://github.com/adamcharnock/django-adminlte2/tree/master/django_adminlte/templatetags.

        :param context: Current page context
        :type context: django.template.context.RequestContext

        :param url_pattern: URL pattern for ``reverse`` matching or raw URL string
        :type url_pattern: str

        :param exact_match: Toggle for exact matching, defaults to False
        :type exact_match: bool, optional

        :param not_when: Comma-separated values of string patterns
            that will render comparison as False, defaults to ''
        :type not_when: str, optional

        :param args: Positional arguments for ``reverse`` matching
        :type args: tuple

        :params kwargs: Keyword arguments for ``reverse`` matching
        :type kwargs: dict

        :return: 'active' if comparison is True, else ''
        :rtype: str
    """
    exact_match = kwargs.pop('exact_match', False)
    not_when = kwargs.pop('not_when', '').split(',')
    not_when = [nw.strip() for nw in not_when if nw.strip()]

    try:
        path = reverse(url_pattern, args=args, kwargs=kwargs)
    except NoReverseMatch:
        path = url_pattern

    current_path = context.request.path

    if not_when and any(nw in current_path for nw in not_when):
        return ''
    elif not exact_match and current_path.startswith(path) or exact_match and current_path == path:
        return ' active '
    return ''


@register.filter
def add_class(field, class_name):
    """
    Add class names to a form field

    Based on a StackOverflow answer:
     https://stackoverflow.com/a/27284041

        :param field: Django Form element
        :type field: django.forms.boundfield.BoundField

        :param class_name: HTML class name value
        :type class_name: django.utils.safestring.SafeString

        :return: Rendered Django Form element with newly-added class name values
        :rtype: django.utils.safestring.SafeString
    """
    return field.as_widget(attrs={
        "class": " ".join((field.css_classes(), class_name))
    })


@register.simple_tag(takes_context=True)
def gravatar_url(context, user=None, size=None, default=None, force_default=None, rating=None):
    """
    Generate a Gravatar image URL based on the current user

    Based on:
     https://github.com/adamcharnock/django-adminlte2/tree/master/django_adminlte/templatetags.

    References:
     https://en.gravatar.com/site/implement/images/
     https://en.gravatar.com/site/implement/images/python/

    :param context: Current page context
    :type context: django.template.context.RequestContext

    :param user: User object, defaults to None (uses User object from context)
    :type user: django.contrib.auth.models.User, optional

    :param size: Image size. You may request images anywhere from 1px up to 2048px. Defaults to 80.
    :type size: int, optional

    :param default: Default image. Available options are:
        * <url>: Image URL path
        * 404: do not load any image if none is associated with the email hash, instead return an HTTP 404 response
        * mp: a simple, cartoon-style silhouetted outline of a person (does not vary by email hash)
        * identicon: a geometric pattern based on an email hash
        * monsterid: a generated 'monster' with different colors, faces, etc
        * wavatar: generated faces with differing features and backgrounds
        * retro: awesome generated, 8-bit arcade-style pixelated faces
        * robohash: a generated robot with different colors, faces, etc
        * blank: a transparent PNG image
    :type default: str, optional

    :param force_default: Toggle to force load default image, defaults to False
    :type force_default: bool, optional

    :param rating: Image rating:
        * g: suitable for display on all websites with any audience type
        * pg: may contain rude gestures, provocatively dressed individuals, the lesser swear words, or mild violence
        * r: may contain such things as harsh profanity, intense violence, nudity, or hard drug use
        * x: may contain hardcore sexual imagery or extremely disturbing violence
    :type rating: str, optional

    :return: Gravatar image URL string
    :rtype: str
    """
    size = size or get_settings('ADMINLTE_GRAVATAR_SIZE')
    default = default or get_settings('ADMINLTE_GRAVATAR_DEFAULT')
    rating = rating or get_settings('ADMINLTE_GRAVATAR_RATING')
    user = context['request'].user if not user else user

    if not const.GRAVATAR_SIZE_MINIMUM <= size <= const.GRAVATAR_SIZE_MAXIMUM:
        raise TemplateSyntaxError('"size" parameter only allows int values from {} to {}'.format(
            const.GRAVATAR_SIZE_MINIMUM, const.GRAVATAR_SIZE_MAXIMUM
        ))

    if default not in const.GRAVATAR_DEFAULT_CHOICES:
        raise TemplateSyntaxError(
            '"default" parameter valid values are: {}'.format(', '.join(const.GRAVATAR_DEFAULT_CHOICES)))

    if rating not in const.GRAVATAR_RATING_CHOICES:
        raise TemplateSyntaxError(
            '"rating" parameter valid values are: {}'.format(', '.join(const.GRAVATAR_RATING_CHOICES)))

    if force_default is None:
        force_default = get_settings('ADMINLTE_GRAVATAR_FORCE_DEFAULT')

    params = [
        ('s', size),
        ('d', default),
        ('r', rating),
    ]

    if force_default:
        params.append(('f', 'y'))

    params = urlencode(params)

    return mark_safe('https://www.gravatar.com/avatar/{hash}?{params}'.format(  # nosec
        hash=hashlib.md5(user.email.encode('utf-8').lower()).hexdigest() if user.is_authenticated else '',  # nosec
        params=params,
    ))


@register.inclusion_tag(filename=const.PAGINATOR_TEMPLATE_NAME, takes_context=True)
def paginator(context, adjacent_pages=2, align='initial', no_margin=False):
    """
    Adds pagination context variables for use in displaying first, adjacent and last page links in addition
    to those created by the object_list generic view.

    Based on:
     http://www.djangosnippets.org/snippets/73/
     http://www.tummy.com/Community/Articles/django-pagination/

        :param context: Current page context
        :type context: django.template.context.RequestContext

        :param adjacent_pages: Adjacent page links to current page link, defaults to 2
        :type adjacent_pages: int, optional

        :param align: Element alignment. Valid values are ``left``, ``right``, ``center``, ``initial``.
            Defaults to ``initial``
        :type align: str, optional

        :param no_margin: Toggle to remove margin around element, defaults to ``False``.
        :type no_margin: bool, optional

        :return: Paginator page context:

            * page_obj     - paginated list objects
            * paginator    - paginator object
            * current_page - current page number
            * last_page    - last page number
            * page_numbers - total number of pages
            * has_prev     - toggle to show previous page link
            * has_next     - toggle to show next page link
            * prev_page    - previous page number
            * next_page    - next page number
            * show_first   - toggle to show first page link
            * show_last    - toggle to show last page link
        :rtype: dict
    """
    page_obj = context['page_obj']
    paginator = context['paginator']
    current_page = page_obj.number
    number_of_pages = paginator.num_pages

    if align == const.PAGINATOR_ALIGN_INITIAL:
        align = ''
    elif align == const.PAGINATOR_ALIGN_CENTER:
        align = 'text-center'
    elif align == const.PAGINATOR_ALIGN_LEFT:
        align = 'pull-left'
    elif align == const.PAGINATOR_ALIGN_RIGHT:
        align = 'pull-right'
    else:
        raise TemplateSyntaxError(
            '"align" parameter valid values are: {}'.format(', '.join(const.PAGINATOR_ALIGN_CHOICES)))

    start_page = max(current_page - adjacent_pages, 1)

    end_page = current_page + adjacent_pages + 1
    if end_page > number_of_pages:
        end_page = number_of_pages + 1

    page_numbers = [n for n in range(start_page, end_page) if 0 < n <= number_of_pages]

    return {
        'page_obj': page_obj,
        'paginator': paginator,
        'current_page': current_page,
        'last_page': number_of_pages,
        'page_numbers': page_numbers,
        'has_prev': page_obj.has_previous(),
        'has_next': page_obj.has_next(),
        'prev_page': page_obj.previous_page_number,
        'next_page': page_obj.next_page_number,
        'show_first': 1 != current_page,
        'show_last': number_of_pages != current_page,
        'align': align,
        'no_margin': no_margin,
    }


@register.simple_tag(takes_context=True)
def page_title(context, page_name=''):
    """
    Generate text for HTML <title>. Supports Django 'sites' framework and 'ListView' pagination.

    :param context: Current page context
    :type context: django.template.context.RequestContext

    :param page_name: Page title text. Adding 'page_name' to the page context will override this parameter.
        Defaults to ''.
    :type page_name: str, optional

    :return: Title text
    :rtype: str
    """

    # Check if pagination is enabled
    page_obj = context.get('page_obj', None)
    paginator = context.get('paginator', None)

    title_format = get_settings('ADMINLTE_TITLE_FORMAT')
    title_pagination_format = get_settings('ADMINLTE_TITLE_FORMAT_PAGINATION')
    divider = get_settings('ADMINLTE_TITLE_DIVIDER')
    site_name = get_settings('ADMINLTE_TITLE_SITE')

    try:
        # Check current page context to override 'page_name' parameter
        page_name = context['page_name']
    except KeyError:
        pass

    try:
        # Get current Site object by SITE_ID
        site_name = Site.objects.get_current().name
    except NameError:
        # If 'sites' is not in INSTALLED_APPS, get site title from settings.py
        pass
    except (ImproperlyConfigured, Site.DoesNotExist):
        # Else if an invalid SITE_ID is provided, get value from current page context
        try:
            site_name = get_current_site(context['request']).name
        except Site.DoesNotExist:
            pass

    params = {
        'site': site_name,
        'divider': divider,
        'page': page_name,
    }

    if page_obj and paginator:
        # If {% page_title %} is used in a ListView, use the title format string with pagination support
        title_format = title_pagination_format
        params.update({'curr_no': page_obj.number, 'last_no': paginator.num_pages, })

    return title_format.format(**params)



from django.contrib.sites.models import Site
from django.test import Client
from django.test import TestCase

from adminlte2_templates.core import reverse


class PageTitleTestCase(TestCase):
    """
    Test cases for {% page_title %} template tag

    Testing these cases:

        * Sanity check
        * 'ADMINLTE_TITLE_SITE', 'ADMINLTE_TITLE_DIVIDER', 'ADMINLTE_TITLE_FORMAT',
            'ADMINLTE_TITLE_FORMAT_PAGINATION' settings
        * 'page_name' param View context override
        * Django 'sites' support
        * ListView support
    """
    URL_PATTERN_INDEX = 'page_title:index'
    URL_PATTERN_LIST = 'page_title:list'
    URL_PATTERN_OVERRIDE = 'page_title:override'

    def setUp(self):
        self.client = Client()

    def add_sites(self):
        for n in range(2):
            Site.objects.create(name=str(n), domain=str(n))

    def add_working_site(self):
        Site.objects.create(domain='testserver', name='testserver')

    def get_response_index(self):
        return self.client.get(reverse(self.URL_PATTERN_INDEX))

    def get_response_list(self, page):
        return self.client.get(reverse(self.URL_PATTERN_LIST) + '?page=' + str(page))

    def get_response_override_page_name(self):
        return self.client.get(reverse(self.URL_PATTERN_OVERRIDE))

    #
    #   Sanity check
    #
    def test_response(self):
        return self.assertContains(self.get_response_index(), 'AdminLTE | Title')

    #
    #   Settings
    #
    def test_settings_site_name(self):
        with self.settings(ADMINLTE_TITLE_SITE='Testing'):
            return self.assertContains(self.get_response_index(), 'Testing | Title')

    def test_settings_divider(self):
        with self.settings(ADMINLTE_TITLE_DIVIDER='@'):
            return self.assertContains(self.get_response_index(), 'AdminLTE @ Title')

    def test_settings_format(self):
        with self.settings(ADMINLTE_TITLE_FORMAT='{site} {divider} {page}'):
            return self.assertContains(self.get_response_index(), 'AdminLTE | Title')

    def test_settings_format_pagination(self):
        with self.settings(ADMINLTE_TITLE_FORMAT_PAGINATION='{site} {divider} {page} ({curr_no} of {last_no})'):
            return self.assertContains(self.get_response_list(1), 'AdminLTE | Title (1 of 1)')

    #
    #   Override page name through View context
    #
    def test_override_context_page_name(self):
        return self.assertContains(self.get_response_override_page_name(), 'AdminLTE | Override')

    #
    #   Django 'sites' support
    #
    def test_sites_site_id(self):
        with self.settings(SITE_ID=1):
            return self.assertContains(self.get_response_index(), 'example.com | Title')

    def test_sites_current_site(self):
        self.add_working_site()
        return self.assertContains(self.get_response_index(), 'testserver | Title')

    def test_sites_failsafe_invalid_site_id(self):
        with self.settings(SITE_ID=2):
            return self.assertContains(self.get_response_index(), 'AdminLTE | Title')

    #
    #   ListView support
    #
    def test_listview_page_1(self):
        self.add_sites()
        return self.assertContains(self.get_response_list(1), 'AdminLTE | Title (1 of 3)')

    def test_listview_page_1_no_add(self):
        return self.assertContains(self.get_response_list(1), 'AdminLTE | Title (1 of 1)')

    def test_listview_page_2(self):
        self.add_sites()
        return self.assertContains(self.get_response_list(2), 'AdminLTE | Title (2 of 3)')

    def test_listview_page_last(self):
        self.add_sites()
        return self.assertContains(self.get_response_list('last'), 'AdminLTE | Title (3 of 3)')



#
#   HTML
#

ADMINLTE_HTML_LANG = 'en-us'
"""
    *(str)* HTML 'lang' attribute value.

    Defaults to ``'en-us'``
"""

ADMINLTE_HTML_LANG_BIDI = 'ltr'
"""
    *(str)* HTML ``dir`` attribute value for handling bidirectional text. 
    
    Valid values are ``'ltr'``, ``'rtl'``, ``'auto'``.
    
    Defaults to ``'ltr'``.
"""

ADMINLTE_USE_SHIM = False
"""
    *(bool)* Toggle to use HTML5 Shim for IE9 support.

    Defaults to ``False``.
"""

#
#   Skin theme
#

# Valid AdminLTE skin style values
SKIN_STYLE_BLACK = 'skin-black'
SKIN_STYLE_BLACK_LIGHT = 'skin-black-light'
SKIN_STYLE_BLUE = 'skin-blue'
SKIN_STYLE_BLUE_LIGHT = 'skin-blue-light'
SKIN_STYLE_GREEN = 'skin-green'
SKIN_STYLE_GREEN_LIGHT = 'skin-green-light'
SKIN_STYLE_PURPLE = 'skin-purple'
SKIN_STYLE_PURPLE_LIGHT = 'skin-purple-light'
SKIN_STYLE_RED = 'skin-red'
SKIN_STYLE_RED_LIGHT = 'skin-red-light'
SKIN_STYLE_YELLOW = 'skin-yellow'
SKIN_STYLE_YELLOW_LIGHT = 'skin-yellow-light'
SKIN_STYLE_CHOICES = (SKIN_STYLE_BLACK, SKIN_STYLE_BLACK_LIGHT, SKIN_STYLE_BLUE, SKIN_STYLE_BLUE_LIGHT,
                      SKIN_STYLE_GREEN, SKIN_STYLE_GREEN_LIGHT, SKIN_STYLE_PURPLE, SKIN_STYLE_PURPLE_LIGHT,
                      SKIN_STYLE_RED, SKIN_STYLE_RED_LIGHT, SKIN_STYLE_YELLOW, SKIN_STYLE_YELLOW_LIGHT)

ADMINLTE_SKIN_STYLE = SKIN_STYLE_BLUE
"""
    *(str)* Default AdminLTE skin style.

    Valid values are: ``'skin-black'``, ``'skin-black-light'``, ``'skin-blue'``, ``'skin-blue-light'``,
    ``'skin-green'``, ``'skin-green-light'``, ``'skin-purple'``, ``'skin-purple-light'``,
    ``'skin-red'``, ``'skin-red-light'``, ``'skin-yellow'``, ``'skin-yellow-light'``.

    Defaults to ``'skin-blue'``.
"""

#
#   Control theme
#

# Valid AdminLTE control sidebar style values
CONTROL_STYLE_DARK = 'control-sidebar-dark'
CONTROL_STYLE_LIGHT = 'control-sidebar-light'
CONTROL_STYLE_CHOICES = (CONTROL_STYLE_DARK, CONTROL_STYLE_LIGHT)

ADMINLTE_CONTROL_STYLE = CONTROL_STYLE_DARK
"""
    *(str)* Default AdminLTE control sidebar style.

    Valid values are: ``'control-sidebar-dark'``, ``'control-sidebar-light'``.

    Defaults to ``'control-sidebar-dark'``.
"""

#
#   CDN
#

ADMINLTE_USE_CDN = False
"""
    *(bool)* Toggle to use CDN links for AdminLTE dependencies.

    Defaults to ``False``.
"""

ADMINLTE_CDN_ADMINLTE_CSS_CORE = 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/AdminLTE.min.css'
"""
    *(str)* CDN link for AdminLTE 2.4.18 core CSS file.

    Defaults to ``'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/AdminLTE.min.css'``.
"""

ADMINLTE_CDN_ADMINLTE_CSS_SKIN = {
    SKIN_STYLE_BLACK: 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-black.min.css',
    SKIN_STYLE_BLACK_LIGHT: 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-black-light.min.css',
    SKIN_STYLE_BLUE: 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-blue.min.css',
    SKIN_STYLE_BLUE_LIGHT: 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-blue-light.min.css',
    SKIN_STYLE_GREEN: 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-green.min.css',
    SKIN_STYLE_GREEN_LIGHT: 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-green-light.min.css',
    SKIN_STYLE_PURPLE: 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-purple.min.css',
    SKIN_STYLE_PURPLE_LIGHT: 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-purple-light.min.css',
    SKIN_STYLE_RED: 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-red.min.css',
    SKIN_STYLE_RED_LIGHT: 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-red-light.min.css',
    SKIN_STYLE_YELLOW: 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-yellow.min.css',
    SKIN_STYLE_YELLOW_LIGHT: 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-yellow-light.min.css',
}
"""
    *(dict)* CDN links for AdminLTE 2.4.18 skin CSS files.

    Valid keys are: ``'skin-black'``, ``'skin-black-light'``, ``'skin-blue'``, ``'skin-blue-light'``,
    ``'skin-green'``, ``'skin-green-light'``, ``'skin-purple'``, ``'skin-purple-light'``,
    ``'skin-red'``, ``'skin-red-light'``, ``'skin-yellow'``, ``'skin-yellow-light'``.

    Default:

    .. code:: python

        {
            'skin-black': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-black.min.css',
            'skin-black-light': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-black-light.min.css',
            'skin-blue': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-blue.min.css',
            'skin-blue-light': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-blue-light.min.css',
            'skin-green': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-green.min.css',
            'skin-green-light': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-green-light.min.css',
            'skin-purple': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-purple.min.css',
            'skin-purple-light': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-purple-light.min.css',
            'skin-red': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-red.min.css',
            'skin-red-light': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-red-light.min.css',
            'skin-yellow': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-yellow.min.css',
            'skin-yellow-light': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-yellow-light.min.css',
        }
"""

ADMINLTE_CDN_ADMINLTE_JS_CORE = 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/js/adminlte.min.js'
"""
    *(str)* CDN link for AdminLTE 2.4.18 core JS file.

    Defaults to ``'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/js/adminlte.min.js'``.
"""

ADMINLTE_CDN_BOOTSTRAP_CSS_CORE = 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.4.1/css/bootstrap.min.css'
"""
    *(str)* CDN link for Bootstrap 3.4.1 core CSS file.

    Defaults to ``'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.4.1/css/bootstrap.min.css'``.
"""

ADMINLTE_CDN_BOOTSTRAP_JS_CORE = 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.4.1/js/bootstrap.min.js'
"""
    *(str)* CDN link for Bootstrap 3.4.1 core JS file.

    Defaults to ``'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.4.1/js/bootstrap.min.js'``.
"""

ADMINLTE_CDN_DATATABLES_CSS_CORE = 'https://cdn.datatables.net/1.10.21/css/jquery.dataTables.min.css'
"""
    *(str)* CDN link for DataTables 1.10.21 core CSS file.

    Defaults to ``'https://cdn.datatables.net/1.10.21/css/jquery.dataTables.min.css'``.
"""

ADMINLTE_CDN_DATATABLES_JS_CORE = 'https://cdn.datatables.net/1.10.21/js/jquery.dataTables.min.js'
"""
    *(str)* CDN link for DataTables 1.10.21 core JS file.
    
    Defaults to ``'https://cdn.datatables.net/1.10.21/js/jquery.dataTables.min.js'``.
"""

ADMINLTE_CDN_FONTAWESOME_CSS_CORE = 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css'
"""
    *(str)* CDN link for Font-Awesome 4.7.0 core CSS file.

    Defaults to ``'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css'``.
"""

ADMINLTE_CDN_JQUERY_JS_CORE = 'https://cdnjs.cloudflare.com/ajax/libs/jquery/3.5.1/jquery.min.js'
"""
    *(str)* CDN link for jQuery 3.5.1 JS file.

    Defaults to ``'https://cdnjs.cloudflare.com/ajax/libs/jquery/3.5.1/jquery.min.js'``.
"""

ADMINLTE_CDN_HTML5SHIV_JS_CORE = 'https://oss.maxcdn.com/html5shiv/3.7.3/html5shiv.min.js'
"""
    *(str)* CDN link for HTML5 Shim script HTML5 Shiv JS file.

    Defaults to ``'https://oss.maxcdn.com/html5shiv/3.7.3/html5shiv.min.js'``.
"""

ADMINLTE_CDN_RESPOND_JS_CORE = 'https://oss.maxcdn.com/respond/1.4.2/respond.min.js'
"""
    *(str)* CDN link for HTML5 Shim script Respond JS file.

    Defaults to ``'https://oss.maxcdn.com/respond/1.4.2/respond.min.js'``.
"""

ADMINLTE_CDN_SELECT2_JS_CORE = 'https://cdn.jsdelivr.net/npm/select2@4.0.13/dist/js/select2.min.js'
"""
    *(str)* CDN link for Select2 4.0.13 core JS file
    
    Defaults to ``'https://cdn.jsdelivr.net/npm/select2@4.0.13/dist/js/select2.min.js'``.
"""

ADMINLTE_CDN_SELECT2_CSS_CORE = 'https://cdn.jsdelivr.net/npm/select2@4.0.13/dist/css/select2.min.css'
"""
    *(str)* CDN link for Select2 4.0.13 core CSS file
    
    Defaults to ``'https://cdn.jsdelivr.net/npm/select2@4.0.13/dist/css/select2.min.css'``.
"""

#
#   Footer
#
ADMINLTE_FOOTER_VERSION = '1.0.0'
"""
    *(str)* Footer version number text, defaults to ``'1.0.0'``.
"""

#
#   Gravatar
#

# Valid Gravatar 'default' parameter values
GRAVATAR_DEFAULT_404 = '404'
GRAVATAR_DEFAULT_MP = 'mp'
GRAVATAR_DEFAULT_IDENTICON = 'identicon'
GRAVATAR_DEFAULT_MONSTERID = 'monsterid'
GRAVATAR_DEFAULT_WAVATAR = 'wavatar'
GRAVATAR_DEFAULT_RETRO = 'retro'
GRAVATAR_DEFAULT_ROBOHASH = 'robohash'
GRAVATAR_DEFAULT_BLANK = 'blank'
GRAVATAR_DEFAULT_CHOICES = (GRAVATAR_DEFAULT_404, GRAVATAR_DEFAULT_MP, GRAVATAR_DEFAULT_IDENTICON,
                            GRAVATAR_DEFAULT_MONSTERID, GRAVATAR_DEFAULT_WAVATAR, GRAVATAR_DEFAULT_RETRO,
                            GRAVATAR_DEFAULT_ROBOHASH, GRAVATAR_DEFAULT_BLANK)

# Valid Gravatar 'rating' parameter values
GRAVATAR_RATING_G = 'g'
GRAVATAR_RATING_PG = 'pg'
GRAVATAR_RATING_R = 'r'
GRAVATAR_RATING_X = 'x'
GRAVATAR_RATING_CHOICES = (GRAVATAR_RATING_G, GRAVATAR_RATING_PG, GRAVATAR_RATING_R, GRAVATAR_RATING_X)

# Valid Gravatar 'size' range
GRAVATAR_SIZE_MINIMUM = 1
GRAVATAR_SIZE_MAXIMUM = 2048

ADMINLTE_GRAVATAR_SIZE = 80
"""
    *(int)* Default Gravatar image size.

    You may request images anywhere from ``1`` up to ``2048``, however note that many users have lower 
    resolution images, so requesting larger sizes may result in pixelation/low-quality images.

    Defaults to ``80``. 
"""

ADMINLTE_GRAVATAR_DEFAULT = GRAVATAR_DEFAULT_MP
"""
    *(str)* Default Gravatar image to load.

    You can supply your own default image by supplying the URL to an image. Alternatively, you can use any of these
    valid values: ``'404'``, ``'mp'``, ``'identicon'``, ``'monsterid'``, ``'wavatar'``, ``'retro'``, 
    ``'robohash'``, ``'blank'``.

    Defaults to ``'mp'``.
"""

ADMINLTE_GRAVATAR_FORCE_DEFAULT = False
"""
    *(bool)* Toggle to force load the default Gravatar image.

    Defaults to ``False``.
"""

ADMINLTE_GRAVATAR_RATING = GRAVATAR_RATING_PG
"""
    *(str)* Gravatar image rating.

    Valid values are: ``'g'``, ``'pg'``, ``'r'``, ``'x'``.

    Defaults to ``'pg'``.
"""

#
#   Layouts
#
_LAYOUT_BOXED_FILENAME = 'boxed.html'
_LAYOUT_COLLAPSED_FILENAME = 'collapsed_sidebar.html'
_LAYOUT_FIXED_FILENAME = 'fixed.html'
_LAYOUT_TOP_NAV_FILENAME = 'top_navigation.html'
_LAYOUT_DEFAULT_DIRECTORY = 'adminlte2/layouts/'
_LAYOUT_BAREBONES_DIRECTORY = 'adminlte2/shortcuts/barebones/'
_LAYOUT_NO_BREADCRUMBS_DIRECTORY = 'adminlte2/shortcuts/no_breadcrumbs/'
_LAYOUT_NO_BREADCRUMBS_FOOTER_DIRECTORY = 'adminlte2/shortcuts/no_breadcrumbs_footer/'
_LAYOUT_NO_FOOTER_DIRECTORY = 'adminlte2/shortcuts/no_footer/'
_LAYOUT_NO_CONTENT_HEADER = 'adminlte2/shortcuts/no_content_header/'
# Default
LAYOUT_DEFAULT_BOXED = _LAYOUT_DEFAULT_DIRECTORY + _LAYOUT_BOXED_FILENAME
LAYOUT_DEFAULT_COLLAPSED = _LAYOUT_DEFAULT_DIRECTORY + _LAYOUT_COLLAPSED_FILENAME
LAYOUT_DEFAULT_FIXED = _LAYOUT_DEFAULT_DIRECTORY + _LAYOUT_FIXED_FILENAME
LAYOUT_DEFAULT_LOGIN = _LAYOUT_DEFAULT_DIRECTORY + 'login.html'
LAYOUT_DEFAULT_REGISTER = _LAYOUT_DEFAULT_DIRECTORY + 'register.html'
LAYOUT_DEFAULT_TOP_NAV = _LAYOUT_DEFAULT_DIRECTORY + _LAYOUT_TOP_NAV_FILENAME
# Barebones
LAYOUT_BAREBONES_BOXED = _LAYOUT_BAREBONES_DIRECTORY + _LAYOUT_BOXED_FILENAME
LAYOUT_BAREBONES_COLLAPSED = _LAYOUT_BAREBONES_DIRECTORY + _LAYOUT_COLLAPSED_FILENAME
LAYOUT_BAREBONES_FIXED = _LAYOUT_BAREBONES_DIRECTORY + _LAYOUT_FIXED_FILENAME
LAYOUT_BAREBONES_TOP_NAV = _LAYOUT_BAREBONES_DIRECTORY + _LAYOUT_TOP_NAV_FILENAME
# No Breadcrumbs
LAYOUT_NO_BREADCRUMBS_BOXED = _LAYOUT_NO_BREADCRUMBS_DIRECTORY + _LAYOUT_BOXED_FILENAME
LAYOUT_NO_BREADCRUMBS_COLLAPSED = _LAYOUT_NO_BREADCRUMBS_DIRECTORY + _LAYOUT_COLLAPSED_FILENAME
LAYOUT_NO_BREADCRUMBS_FIXED = _LAYOUT_NO_BREADCRUMBS_DIRECTORY + _LAYOUT_FIXED_FILENAME
LAYOUT_NO_BREADCRUMBS_TOP_NAV = _LAYOUT_NO_BREADCRUMBS_DIRECTORY + _LAYOUT_TOP_NAV_FILENAME
# No Breadcrumbs, No Footer
LAYOUT_NO_BREADCRUMBS_FOOTER_BOXED = _LAYOUT_NO_BREADCRUMBS_FOOTER_DIRECTORY + _LAYOUT_BOXED_FILENAME
LAYOUT_NO_BREADCRUMBS_FOOTER_COLLAPSED = _LAYOUT_NO_BREADCRUMBS_FOOTER_DIRECTORY + _LAYOUT_COLLAPSED_FILENAME
LAYOUT_NO_BREADCRUMBS_FOOTER_FIXED = _LAYOUT_NO_BREADCRUMBS_FOOTER_DIRECTORY + _LAYOUT_FIXED_FILENAME
LAYOUT_NO_BREADCRUMBS_FOOTER_TOP_NAV = _LAYOUT_NO_BREADCRUMBS_FOOTER_DIRECTORY + _LAYOUT_TOP_NAV_FILENAME
# No Content Header
LAYOUT_NO_CONTENT_HEADER_BOXED = _LAYOUT_NO_CONTENT_HEADER + _LAYOUT_BOXED_FILENAME
LAYOUT_NO_CONTENT_HEADER_COLLAPSED = _LAYOUT_NO_CONTENT_HEADER + _LAYOUT_COLLAPSED_FILENAME
LAYOUT_NO_CONTENT_HEADER_FIXED = _LAYOUT_NO_CONTENT_HEADER + _LAYOUT_FIXED_FILENAME
LAYOUT_NO_CONTENT_HEADER_TOP_NAV = _LAYOUT_NO_CONTENT_HEADER + _LAYOUT_TOP_NAV_FILENAME
# No Footer
LAYOUT_NO_FOOTER_BOXED = _LAYOUT_NO_FOOTER_DIRECTORY + _LAYOUT_BOXED_FILENAME
LAYOUT_NO_FOOTER_COLLAPSED = _LAYOUT_NO_FOOTER_DIRECTORY + _LAYOUT_COLLAPSED_FILENAME
LAYOUT_NO_FOOTER_FIXED = _LAYOUT_NO_FOOTER_DIRECTORY + _LAYOUT_FIXED_FILENAME
LAYOUT_NO_FOOTER_TOP_NAV = _LAYOUT_NO_FOOTER_DIRECTORY + _LAYOUT_TOP_NAV_FILENAME

#
#   Static files
#
ADMINLTE_STATIC_ENABLE_DATATABLES = True
"""
    *(bool)* Toggle to enable the Datatables library (https://www.datatables.net/) included out-of-the-box.
    
    Defaults to ``True``.
"""

ADMINLTE_STATIC_ENABLE_FONTAWESOME = True
"""
    *(bool)* Toggle to enable the Font Awesome library (https://fontawesome.com/v4.7.0/icons/) included out-of-the-box.
    
    Defaults to ``True``.
"""

ADMINLTE_STATIC_ENABLE_SELECT2 = True
"""
    *(bool)* Toggle to enable the Select2 library (https://select2.org/) included out-of-the-box.
    
    Defaults to ``True``.
"""

#
#   Paginator
#
PAGINATOR_ALIGN_INITIAL = 'initial'
PAGINATOR_ALIGN_CENTER = 'center'
PAGINATOR_ALIGN_LEFT = 'left'
PAGINATOR_ALIGN_RIGHT = 'right'
PAGINATOR_ALIGN_CHOICES = (PAGINATOR_ALIGN_INITIAL, PAGINATOR_ALIGN_CENTER, PAGINATOR_ALIGN_LEFT, PAGINATOR_ALIGN_RIGHT)
PAGINATOR_TEMPLATE_NAME = 'adminlte2/extras/paginator.html'

#
#   Page title
#

ADMINLTE_TITLE_FORMAT = '{site} {divider} {page}'
"""
    *(str)* Page title string format.
    
    Supported string format parameters are:
    
    - **site**: Site name
    - **divider**: Divider character between the site name and current page name
    - **page**: Current page name
    
    Defaults to ``'{site} {divider} {page}'``.
"""

ADMINLTE_TITLE_FORMAT_PAGINATION = '{site} {divider} {page} ({curr_no} of {last_no})'
"""
    *(str)* Page title string format for pages with pagination (ListView, etc.)
    
    Supported string format parameters are:
    
    - **site**: Site name
    - **divider**: Divider character between the site name and current page name
    - **page**: Current page name
    - **curr_no**: Current page number
    - **last_no**: Last page number
    
    Defaults to ``'{site} {divider} {page} ({curr_no} of {last_no})'``.
"""

ADMINLTE_TITLE_SITE = 'AdminLTE'
"""
    *(str)* Page title site name text.
    
    Defaults to ``'AdminLTE'``.
"""

ADMINLTE_TITLE_DIVIDER = '|'
"""
    *(str)* Page title divider for page name and site name.
    
    Defaults to ``'|'``.
"""
